"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
exports.isTagLine = (line) => {
    return _.some([
        /^[\w-]+(\s+)?:[^//]/.test(line),
        /^[\w-]+(\s+)?:$/.test(line),
    ]);
};
exports.parseTagLine = (line) => {
    const firstColonIndex = _.indexOf(line, ':');
    return {
        key: line.slice(0, firstColonIndex).trim(),
        value: line.slice(firstColonIndex + 1).trim() || undefined,
    };
};
exports.parseFooterTagLines = (footerTagLines, options = {}) => {
    return _.chain(footerTagLines)
        .reject(line => {
        return _.isEmpty(line.trim());
    })
        .reduce((tags, tagLine) => {
        const tag = exports.parseTagLine(tagLine);
        tags.push([tag.key, tag.value]);
        if (options.lowerCaseFooterTags) {
            tags.push([tag.key.toLowerCase(), tag.value]);
        }
        return tags;
    }, [])
        .fromPairs()
        .value();
};
//# sourceMappingURL=tags.js.map